import { Component } from "react";
import { View, Text, Image } from "@tarojs/components";
import "./index.less";
import { AtDivider,AtActivityIndicator } from "taro-ui";
import level from "../../../images/partner/level.png";
import Taro from "@tarojs/taro";
import vip from "../../../images/earningsOrder/vip.png";
import { getPartnerDetail } from "../../../service";
export default class Index extends Component {
  state = {
    orderList: [
      {
        order_number: "XY202403210001",
        pay_time: "2024-03-21 15:30:25",
        item_pic_url: "https://example.com/product1.jpg",
        item_title: "2024春季新款连衣裙",
        assess_amount_text: "12.50",
        actual_paid_fee: "299.00",
      },
      {
        order_number: "XY202403200015",
        pay_time: "2024-03-20 10:15:33",
        item_pic_url: "https://example.com/product2.jpg",
        item_title: "时尚百搭小白鞋",
        assess_amount_text: "8.80",
        actual_paid_fee: "219.00",
      },
      {
        order_number: "XY202403190089",
        pay_time: "2024-03-19 18:45:12",
        item_pic_url: "https://example.com/product3.jpg",
        item_title: "韩版宽松牛仔外套",
        assess_amount_text: "15.00",
        actual_paid_fee: "358.00",
      },
    ],
    page: 1, //页数
    loading: false, //加载状态
    totalPages: 1, // 添加总页数
    isNoMore: false,
  };
  componentDidMount() {
    this.getPartnerDetail(true);
  }
  // 获取收益订单列表
  getPartnerDetail = async (isRefresh=false) => {
    const { page } = this.state;
    this.setState({ loading: true });

    const res = await getPartnerDetail({
      page,
      page_size: 10,
    });

    this.setState((prevState) => ({
      orderList: isRefresh
        ? res.income_list
        : [...prevState.orderList, ...res.income_list],
      totalPages: res.total_pages,
      loading: false,
      isNoMore: res.total_pages <= page,
    }));
  };
  // 复制
  handleCopy = async (text) => {
    try {
      await Taro.setClipboardData({
        data: text,
      });
      Taro.showToast({
        title: "内容已复制",
        icon: "success",
        duration: 2000,
      });
    } catch (error) {
      Taro.showToast({
        title: "复制失败",
        icon: "error",
        duration: 2000,
      });
    }
  };
  // 页面上拉触底
  onReachBottom = () => {
    const { page, totalPages, loading } = this.state;
    if (page < totalPages && !loading) {
      this.setState(
        (prevState) => ({ page: prevState.page + 1 }),
        () => this.getPartnerDetail()
      );
    }
  };
  render() {
    const { orderList,loading,isNoMore } = this.state;
    return (
      <View className="index">
        <View className="container">
          <View className="header">
            <View className="header-left">
              <Text className="name">张三</Text>
              <View className="level">
                <Image className="level-icon" src={level} />
                <Text className="level-text">导购员</Text>
              </View>
            </View>
            <View className="header-right">
              <Image className="header-right-avatar" src="" />
            </View>
          </View>
          {/* 个人资料 */}
          <View className="personal-info">
            <View className="info-top">
              <View className="personal-info-item">
                <Text className="personal-info-item-label">累计贡献返利</Text>
                <Text className="personal-info-item-value">￥0.00</Text>
              </View>
              <View className="line"></View>
              <View className="personal-info-item">
                <Text className="personal-info-item-label">累计贡献管理奖</Text>
                <Text className="personal-info-item-value">￥0.00</Text>
              </View>
            </View>
            <View className="line-column"></View>
            <View className="info-bottom">
              <View className="personal-info-item">
                <Text className="personal-info-item-label">手机号</Text>
                <Text className="personal-info-item-value">138****8888</Text>
              </View>
              <View className="line"></View>
              <View className="personal-info-item">
                <Text className="personal-info-item-label">推荐绑定时间</Text>
                <Text className="personal-info-item-value">
                  2024-03-21 12:00:00
                </Text>
              </View>
            </View>
          </View>
          {/* 订单列表 */}
          <View className="order-list">
            {orderList.map((item, index) => (
              <View className="order-item" key={index}>
                {/* 订单信息 */}
                <View className="order-info">
                  <View className="order-details">
                    <View className="detail-item">
                      <Text className="label">订单编号:</Text>
                      <Text className="value">{item.order_number}</Text>
                      <Text
                        className="copy-text"
                        onClick={() => this.handleCopy(item.order_number)}
                      >
                        复制
                      </Text>
                    </View>
                    <View className="detail-item">
                      <Text className="label">下单时间:</Text>
                      <Text className="value">{item.pay_time}</Text>
                    </View>
                  </View>
                  {/* <View className="member-info">
                    <Image className="member-icon" src={vip} />
                    <Text className="member-text">闲鱼会员</Text>
                  </View> */}
                </View>

                {/* 产品信息 */}
                <View className="product-info">
                  <Image
                    mode="aspectFill"
                    className="product-image"
                    src={item.item_pic_url}
                  />
                  <View className="product-details">
                    <Text className="product-name">{item.item_title}</Text>
                    <View className="promotion-info">
                      <View className="tag">推广收入</View>
                      <Text className="amount">¥{item.assess_amount_text}</Text>
                    </View>
                    <View className="payment-info">
                      <Text className="label">实付金额:</Text>
                      <Text className="amount">¥{item.actual_paid_fee}</Text>
                    </View>
                  </View>
                </View>
              </View>
            ))}
          </View>
          {orderList.length === 0 && (
            <AtDivider
              content="暂无成交订单"
              fontColor="#B5B5B5"
              lineColor="#D8D8D8"
            />
          )}
          {/* 加载中 */}
          {loading && (
            <View className="loading">
              <AtActivityIndicator
                content="加载中..."
                isOpened={loading}
                mode="center"
                color="#fdf764"
              />
            </View>
          )}
          {/* 没有更多 */}
          {isNoMore && (
            <View className="no-more">
              <AtDivider
                fontSize={18}
                fontColor="#949494"
                content="我是有底线的"
              />
            </View>
          )}
        </View>
      </View>
    );
  }
}
